==> hdf5-1.8.20.tar.bz2: hdf5-1.8.20/src/H5HFpublic.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright by The HDF Group.                                               *
 * Copyright by the Board of Trustees of the University of Illinois.         *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF5.  The full HDF5 copyright notice, including     *
 * terms governing use, modification, and redistribution, is contained in    *
 * the COPYING file, which can be found at the root of the source code       *
 * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
 * If you do not have access to either file, you may request a copy from     *
 * help@hdfgroup.org.                                                        *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*-------------------------------------------------------------------------
 *
 * Created:             H5HFpublic.h
 *                      Feb 24 2006
 *                      Quincey Koziol <koziol@ncsa.uiuc.edu>
 *
 * Purpose:             Public declarations for the fractal heap package.
 *
 *-------------------------------------------------------------------------
 */

#ifndef _H5HFpublic_H
#define _H5HFpublic_H

/* Public headers needed by this file */
#include "H5public.h"

/*****************/
/* Public Macros */
/*****************/

/*******************/
/* Public Typedefs */
/*******************/

/**********************************/
/* Public API Function Prototypes */
/**********************************/

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
}
#endif

#endif /* _H5HFpublic_H */

==> hdf5-1.8.23.tar.bz2: hdf5-1.8.23/src/H5HFpublic.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright by The HDF Group.                                               *
 * Copyright by the Board of Trustees of the University of Illinois.         *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF5.  The full HDF5 copyright notice, including     *
 * terms governing use, modification, and redistribution, is contained in    *
 * the COPYING file, which can be found at the root of the source code       *
 * distribution tree, or in https://www.hdfgroup.org/licenses.               *
 * If you do not have access to either file, you may request a copy from     *
 * help@hdfgroup.org.                                                        *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*-------------------------------------------------------------------------
 *
 * Created:             H5HFpublic.h
 *                      Feb 24 2006
 *                      Quincey Koziol
 *
 * Purpose:             Public declarations for the fractal heap package.
 *
 *-------------------------------------------------------------------------
 */

#ifndef H5HFpublic_H
#define H5HFpublic_H

/* Public headers needed by this file */
#include "H5public.h"

/*****************/
/* Public Macros */
/*****************/

/*******************/
/* Public Typedefs */
/*******************/

/**********************************/
/* Public API Function Prototypes */
/**********************************/

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
}
#endif

#endif /* H5HFpublic_H */
